update

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 5, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the update type in the database.
	Label = "update"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTitle holds the string denoting the title field in the database.
	FieldTitle = "title"
	// FieldDate holds the string denoting the date field in the database.
	FieldDate = "date"
	// FieldSupportURL holds the string denoting the support_url field in the database.
	FieldSupportURL = "support_url"
	// EdgeOwner holds the string denoting the owner edge name in mutations.
	EdgeOwner = "owner"
	// AgentFieldID holds the string denoting the ID field of the Agent.
	AgentFieldID = "oid"
	// Table holds the table name of the update in the database.
	Table = "updates"
	// OwnerTable is the table that holds the owner relation/edge.
	OwnerTable = "updates"
	// OwnerInverseTable is the table name for the Agent entity.
	// It exists in this package in order to avoid circular dependency with the "agent" package.
	OwnerInverseTable = "agents"
	// OwnerColumn is the table column denoting the owner relation/edge.
	OwnerColumn = "agent_updates"
)

Variables

Columns holds all SQL columns for update fields.

var ForeignKeys = []string{
	"agent_updates",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "updates" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.Update) predicate.Update

And groups predicates with the AND operator between them.

func Date

func Date(v time.Time) predicate.Update

Date applies equality check predicate on the "date" field. It's identical to DateEQ.

func DateEQ

func DateEQ(v time.Time) predicate.Update

DateEQ applies the EQ predicate on the "date" field.

func DateGT

func DateGT(v time.Time) predicate.Update

DateGT applies the GT predicate on the "date" field.

func DateGTE

func DateGTE(v time.Time) predicate.Update

DateGTE applies the GTE predicate on the "date" field.

func DateIn

func DateIn(vs ...time.Time) predicate.Update

DateIn applies the In predicate on the "date" field.

func DateLT

func DateLT(v time.Time) predicate.Update

DateLT applies the LT predicate on the "date" field.

func DateLTE

func DateLTE(v time.Time) predicate.Update

DateLTE applies the LTE predicate on the "date" field.

func DateNEQ

func DateNEQ(v time.Time) predicate.Update

DateNEQ applies the NEQ predicate on the "date" field.

func DateNotIn

func DateNotIn(vs ...time.Time) predicate.Update

DateNotIn applies the NotIn predicate on the "date" field.

func HasOwner

func HasOwner() predicate.Update

HasOwner applies the HasEdge predicate on the "owner" edge.

func HasOwnerWith

func HasOwnerWith(preds ...predicate.Agent) predicate.Update

HasOwnerWith applies the HasEdge predicate on the "owner" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Update

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Update

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Update

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Update

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Update

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Update

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Update

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Update

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Update

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Update) predicate.Update

Or groups predicates with the OR operator between them.

func SupportURL

func SupportURL(v string) predicate.Update

SupportURL applies equality check predicate on the "support_url" field. It's identical to SupportURLEQ.

func SupportURLContains

func SupportURLContains(v string) predicate.Update

SupportURLContains applies the Contains predicate on the "support_url" field.

func SupportURLContainsFold

func SupportURLContainsFold(v string) predicate.Update

SupportURLContainsFold applies the ContainsFold predicate on the "support_url" field.

func SupportURLEQ

func SupportURLEQ(v string) predicate.Update

SupportURLEQ applies the EQ predicate on the "support_url" field.

func SupportURLEqualFold

func SupportURLEqualFold(v string) predicate.Update

SupportURLEqualFold applies the EqualFold predicate on the "support_url" field.

func SupportURLGT

func SupportURLGT(v string) predicate.Update

SupportURLGT applies the GT predicate on the "support_url" field.

func SupportURLGTE

func SupportURLGTE(v string) predicate.Update

SupportURLGTE applies the GTE predicate on the "support_url" field.

func SupportURLHasPrefix

func SupportURLHasPrefix(v string) predicate.Update

SupportURLHasPrefix applies the HasPrefix predicate on the "support_url" field.

func SupportURLHasSuffix

func SupportURLHasSuffix(v string) predicate.Update

SupportURLHasSuffix applies the HasSuffix predicate on the "support_url" field.

func SupportURLIn

func SupportURLIn(vs ...string) predicate.Update

SupportURLIn applies the In predicate on the "support_url" field.

func SupportURLIsNil

func SupportURLIsNil() predicate.Update

SupportURLIsNil applies the IsNil predicate on the "support_url" field.

func SupportURLLT

func SupportURLLT(v string) predicate.Update

SupportURLLT applies the LT predicate on the "support_url" field.

func SupportURLLTE

func SupportURLLTE(v string) predicate.Update

SupportURLLTE applies the LTE predicate on the "support_url" field.

func SupportURLNEQ

func SupportURLNEQ(v string) predicate.Update

SupportURLNEQ applies the NEQ predicate on the "support_url" field.

func SupportURLNotIn

func SupportURLNotIn(vs ...string) predicate.Update

SupportURLNotIn applies the NotIn predicate on the "support_url" field.

func SupportURLNotNil

func SupportURLNotNil() predicate.Update

SupportURLNotNil applies the NotNil predicate on the "support_url" field.

func Title

func Title(v string) predicate.Update

Title applies equality check predicate on the "title" field. It's identical to TitleEQ.

func TitleContains

func TitleContains(v string) predicate.Update

TitleContains applies the Contains predicate on the "title" field.

func TitleContainsFold

func TitleContainsFold(v string) predicate.Update

TitleContainsFold applies the ContainsFold predicate on the "title" field.

func TitleEQ

func TitleEQ(v string) predicate.Update

TitleEQ applies the EQ predicate on the "title" field.

func TitleEqualFold

func TitleEqualFold(v string) predicate.Update

TitleEqualFold applies the EqualFold predicate on the "title" field.

func TitleGT

func TitleGT(v string) predicate.Update

TitleGT applies the GT predicate on the "title" field.

func TitleGTE

func TitleGTE(v string) predicate.Update

TitleGTE applies the GTE predicate on the "title" field.

func TitleHasPrefix

func TitleHasPrefix(v string) predicate.Update

TitleHasPrefix applies the HasPrefix predicate on the "title" field.

func TitleHasSuffix

func TitleHasSuffix(v string) predicate.Update

TitleHasSuffix applies the HasSuffix predicate on the "title" field.

func TitleIn

func TitleIn(vs ...string) predicate.Update

TitleIn applies the In predicate on the "title" field.

func TitleLT

func TitleLT(v string) predicate.Update

TitleLT applies the LT predicate on the "title" field.

func TitleLTE

func TitleLTE(v string) predicate.Update

TitleLTE applies the LTE predicate on the "title" field.

func TitleNEQ

func TitleNEQ(v string) predicate.Update

TitleNEQ applies the NEQ predicate on the "title" field.

func TitleNotIn

func TitleNotIn(vs ...string) predicate.Update

TitleNotIn applies the NotIn predicate on the "title" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Update queries.

func ByDate

func ByDate(opts ...sql.OrderTermOption) OrderOption

ByDate orders the results by the date field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByOwnerField

func ByOwnerField(field string, opts ...sql.OrderTermOption) OrderOption

ByOwnerField orders the results by owner field.

func BySupportURL

func BySupportURL(opts ...sql.OrderTermOption) OrderOption

BySupportURL orders the results by the support_url field.

func ByTitle

func ByTitle(opts ...sql.OrderTermOption) OrderOption

ByTitle orders the results by the title field.

Jump to